@@ -76,6 +76,7 @@ map.x
 SELECT update
 SELECT x.update
 SELECT call.x
+SELECT end
 a.b.INT(1.234)
 INT(x / 100)
 time * 100
@@ -269,6 +270,8 @@ SELECT x LIKE '%x%' FROM test
 SELECT * FROM test LIMIT 100
 SELECT * FROM test LIMIT 1 + 1
 SELECT * FROM test LIMIT 100 OFFSET 200
+SELECT * FROM test LIMIT (SELECT 1)
+SELECT * FROM test LIMIT (SELECT 1) OFFSET (SELECT 1)
 SELECT * FROM test FETCH FIRST ROWS ONLY
 SELECT * FROM test FETCH FIRST 1 ROWS ONLY
 SELECT * FROM test ORDER BY id DESC FETCH FIRST 10 ROWS WITH TIES
